from distutils.core import setup


setup(
    name="file_operator_zxw",
    version="1.3",
    description="文件常用操作",
    author="XueWei Zhang",
    author_email="307080785@qq.com",
    py_modules=['file_operator_zxw.扫描文件','file_operator_zxw.创建文件夹','file_operator_zxw.识别移动硬盘',
                'file_operator_zxw.get项目根目录','file_operator_zxw.获取磁盘剩余空间','file_operator_zxw.创建excel流',
                'file_operator_zxw.获取文件占用空间',]
)
